package com.qmth.sop.business.activiti.service;

import com.qmth.sop.business.bean.bean.FormPropertyBean;
import com.qmth.sop.business.bean.result.FlowViewResult;
import com.qmth.sop.common.enums.FlowApprovePassEnum;
import com.qmth.sop.common.enums.TFCustomTypeEnum;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * @Description: activiti service
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2021/7/12
 */
public interface ActivitiService {

    /**
     * 根据deploymentId查找processDefinitionId
     *
     * @param deploymentId
     * @return
     */
    String findProcessDefinitionIdByDeploymentId(String deploymentId);

    /**
     * 上传流程
     *
     * @param file
     * @return
     * @throws IOException
     */
    public Map<String, Object> upload(MultipartFile file) throws IOException;

    /**
     * 部署流程
     *
     * @param tfCustomTypeEnumList
     * @return
     * @throws IOException
     */
    public Map<String, Object> createDeployment(List<TFCustomTypeEnum> tfCustomTypeEnumList) throws IOException;

    /**
     * 审批任务
     *
     * @param flowDeploymentId
     * @param approve
     * @param taskId
     * @param formProperties
     * @param approveUserIds
     * @param approveRemark
     * @param map
     * @return
     */
    public Map<String, Object> taskApprove(String flowDeploymentId,
                                           FlowApprovePassEnum approve,
                                           Long taskId,
                                           String formProperties,
                                           List<String> approveUserIds,
                                           String approveRemark,
                                           Map<String, Object> map);

    /**
     * 获取流程表单属性接口
     *
     * @param flowDeploymentId
     * @param flowId
     * @param taskId
     * @return
     */
    public Map<String, Object> formPropertiesGet(String flowDeploymentId, Long flowId, Long taskId);

    /**
     * 获取用户待办
     *
     * @param userId
     * @return
     */
    public List<FormPropertyBean> getTaskList(Long userId);

    /**
     * 流程节点转他人审批
     *
     * @param userId
     * @param taskId
     * @return
     */
    public Boolean taskApproverExchange(Long userId, Long taskId);

    /**
     * 流程终止
     *
     * @param flowId
     * @return
     */
    public Boolean flowEnd(Long flowId);

    /**
     * 获取流程详细信息接口
     *
     * @param flowId
     * @return
     */
    public FlowViewResult flowView(Long flowId);
}
